import { Request, Response } from "express";
import DynamicQueryBuilder from "../../../helpers/dynamicQueryBuilder";
import { dataSource } from "../../../data-source";

/**
 * @description get all table metas
 * @param req {Request} Express req object
 * @param res {Response} Express res object
 * @returns {Promise<*>}
 */
export async function getAllTableMeta(req: Request, res: Response): Promise<any> {
  let tableMetas = DynamicQueryBuilder.getAllTableMeta();

  res.json(tableMetas);
}

/**
 * @description get meta by tablename
 * @param req {Request} Express req object
 * @param res {Response} Express res object
 * @returns {Promise<*>}
 */
export async function getTableMetaByTablename(req: Request, res: Response): Promise<any> {
  const tablename = req.params.tablename;
  let tableMeta = DynamicQueryBuilder.getTableMeta(tablename);

  res.json(tableMeta);
}

/**
 * @description execute Query
 * @param req {Request} Express req object
 * @param res {Response} Express res object
 * @returns {Promise<*>}
 */
export async function executeQuery(req: Request, res: Response): Promise<any> {
  let offset = parseInt((req.query.offset as string) ?? "0");
  let count = parseInt((req.query.count as string) ?? "25");
  const query = req.body.query;

  let result = await DynamicQueryBuilder.executeQuery(query, offset, count);

  res.json(result);
}
